@@ -335,7 +335,7 @@ def edit_config(model_selected, config_output_dir, num_steps, label_map_path, re
 def train(ckpt_dir='', config='', train_steps=1000, use_tpu=False, checkpoint_every_n=100,
           record_summaries=True):
 
-    if config.endswith('.config')
+    if config.endswith('.config'):
         if not os.path.isfile(config):
             raise FileNotFoundError('No config file found at {}'.format(config)) 
     else:
@@ -477,7 +477,7 @@ def evaluate(metrics_dir='', config='', ckpt_dir=''):
         Returns:
             A dictionnary of metrics ready to be sent to the picsell.ia platform.
     '''
-    if config.endswith('.config')
+    if config.endswith('.config'):
         if not os.path.isfile(config):
             raise FileNotFoundError('No config file found at {}'.format(config)) 
     else:
@@ -513,7 +513,7 @@ def tf_events_to_dict(path, type=''):
             A dictionnary of scalars logs.
     '''
     log_dict = {}
-    if path.startswith('events.out')
+    if path.startswith('events.out'):
         if not os.path.isfile(path):
             raise FileNotFoundError('No tfEvent file found at {}'.format(path)) 
     else:
